@@ -53,29 +53,3 @@ $d->add_step($_) for @load_steps;
 
 $d->do_all;
 
-__END__
-
-=pod
-
-=head1 NAME 
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 AUTHOR
-
-Yuval Kogman, E<lt>nothingmuch@woobling.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2005 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
-
-=cut
-
-
